package
Version:
v0.0.0-...-6263c15
Opens a new window with list of versions in this module.
Published: May 30, 2024
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
A simple math package for basic number comparisons
func Clamp[T Number](x T, min T, max T) T
func Max[T Number](a T, b T) T
func Min[T Number](a T, b T) T
Source Files
¶
Click to show internal directories.
Click to hide internal directories.